﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.IO;
using Infragistics.Windows.DataPresenter;
using System.Windows.Media.Animation;
using System.Windows.Threading;
using System.Diagnostics;

namespace MusicPlayerXDG
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        DataRecord playingRecord = null;
        Button playingButton = null;
        DispatcherTimer timer = new DispatcherTimer() { Interval = TimeSpan.FromSeconds(1) };
        public Window1()
        {
            InitializeComponent();
            EventManager.RegisterClassHandler(typeof(DataRecordPresenter),DataRecordPresenter.PreviewMouseDoubleClickEvent,
                new MouseButtonEventHandler(presenter_PreviewMouseDoubleClick));
            me.MediaFailed += new EventHandler<ExceptionRoutedEventArgs>(me_MediaFailed);
            me.MediaEnded += new RoutedEventHandler(me_MediaEnded);
            me.MediaOpened += new RoutedEventHandler(me_MediaOpened);
            timer.Tick += new EventHandler(timer_Tick);
            Loaded += new RoutedEventHandler(Window1_Loaded);
        }

        void presenter_PreviewMouseDoubleClick(object sender, MouseButtonEventArgs e)
        {
            DataRecord dr = (sender as DataRecordPresenter).Record as DataRecord;
            Button button = Infragistics.Windows.Utilities.GetDescendantFromType(sender as DependencyObject,
                typeof(Button),false) as Button;
            PlayMedia(dr, button);
        }

        void me_MediaFailed(object sender, ExceptionRoutedEventArgs e)
        {
            timer.Stop();
        }

        void me_MediaEnded(object sender, RoutedEventArgs e)
        {
            timer.Stop();
            PlayMedia(xamDataGrid1.Records[playingRecord.Index + 1] as DataRecord,playingButton);
        }

        void me_MediaOpened(object sender, RoutedEventArgs e)
        {
            timer.Start();
        }

        void Window1_Loaded(object sender, RoutedEventArgs e)
        {
            DirectoryInfo directory = new DirectoryInfo(@"E:\Music\mc\mp3 17");
            if (directory.Exists)
            {
                FileInfo[] files = directory.GetFiles("*.mp3");
                foreach (FileInfo file in files)
                    xamDataGrid1.DataItems.Add(new MediaFile() { Name = file.Name, FullName = file.FullName, Length = file.Length / (1024 * 1024) });
            }
        }

        void timer_Tick(object sender, EventArgs e)
        {
            double position = me.Position.TotalSeconds;
            double fullLength = me.NaturalDuration.HasTimeSpan ? me.NaturalDuration.TimeSpan.TotalSeconds : 0;

            double percentage = position / fullLength;

            playingRecord.Tag = percentage;
            Debug.WriteLine(percentage);
        }

        private void TextBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            string dir = (sender as TextBox).Text;

            if (Directory.Exists(dir))
            {
                this.Cursor = Cursors.Wait;
                DirectoryInfo directory = new DirectoryInfo(dir);
                FileInfo[] files = directory.GetFiles("*.mp3");
                foreach (FileInfo file in files)
                    xamDataGrid1.DataItems.Add(new MediaFile() { Name = file.Name, FullName = file.FullName, Length = file.Length / (1024 * 1024) });

                this.ClearValue(Window.CursorProperty);
            }
            else
            {
                if (dir.Contains("http"))
                    xamDataGrid1.DataItems.Add(dir);
            }
        }

        private void button_Click(object sender, RoutedEventArgs e)
        {
            if(playingButton!=sender as Button && playingButton!=null)
                playingButton.Content= "Play";
            playingButton = sender as Button;
            PlayMedia((playingButton).DataContext as DataRecord, playingButton);
        }

        private void PlayMedia(DataRecord record, Button button)
        {
            if (playingRecord == null)
            {
                playingRecord = record;

                if (playingRecord != record)
                {
                    playingRecord.Tag = 0;
                }
                playingRecord = record;
                if (playingRecord.DataItem is MediaFile)
                {
                    MediaFile file = (playingRecord).DataItem as MediaFile;
                    me.Source = new Uri(file.FullName, UriKind.RelativeOrAbsolute);
                }
                else
                {
                    me.Source = new Uri(playingRecord.Cells[0].Value.ToString(), UriKind.RelativeOrAbsolute);
                }
                me.Play();
                button.Content = "Resume";
            }
            else
            {
                if (playingRecord != record)
                {
                    playingRecord.Tag = 0;
                    playingRecord = record;
                    timer.IsEnabled = true;
                    MediaFile file = (playingRecord).DataItem as MediaFile;
                    me.Source = new Uri(file.FullName, UriKind.RelativeOrAbsolute);
                    me.Play();
                    button.Content = "Resume";
                }
                else
                {
                    if (timer.IsEnabled)
                    {
                        me.Pause();
                        timer.IsEnabled = false;
                        button.Content = "Play";

                    }
                    else
                    {
                        me.Play();
                        timer.IsEnabled = true;
                        button.Content = "Resume";

                    }
                }
               
            }
        }
    }

    public class MediaFile
    {
        public string Name { get; set; }
        public string FullName { get; set; }
        public double Length { get; set; }
    }
}
